import axios from "axios";
import * as Vue from "vue";
import * as VueQuery from "@tanstack/vue-query";
import viteSSR, { ClientOnly } from "vite-ssr";
import { vueCatchHrefs } from "./vue-catch-hrefs.mjs";
import * as VueUnhead from "@unhead/vue";
import App from "./components/App.vue";
const createVueAppLib = {
  install(app, {
    initialState = {},
    installVueCatchHrefs = false,
    installVueUnHead = false,
    router,
    ssr = false
  }) {
    const queryClient = new VueQuery.QueryClient();
    app.use(VueQuery.VueQueryPlugin, { queryClient });
    app.config.globalProperties.$axios = axios;
    app.config.globalProperties.$VueQuery = VueQuery;
    app.config.globalProperties.$Vue = Vue;
    if (ssr) {
      initialState.vueQueryState = {
        toJSON: () => VueQuery.dehydrate(queryClient)
      };
    } else {
      if (installVueCatchHrefs) {
        app.use(vueCatchHrefs, { router });
      }
      VueQuery.hydrate(queryClient, initialState.vueQueryState);
    }
    app.component(ClientOnly.name, ClientOnly);
    if (installVueUnHead) {
      const head = VueUnhead.createHead();
      app.use(head);
      app.mixin(VueUnhead.VueHeadMixin);
    }
  }
};
function viteSSRByWeber({
  routes,
  options,
  hook,
  ssr,
  createVueAppLibOptions
}) {
  return viteSSR(
    App,
    { pageProps: { passToPage: false }, ...options, routes },
    async ({ app, initialState, router }) => {
      app.use(createVueAppLib, {
        router,
        initialState,
        ssr,
        installVueCatchHrefs: createVueAppLibOptions?.installVueCatchHrefs || false,
        installVueUnHead: createVueAppLibOptions?.installVueUnHead || false
      });
      const hookResponse = await hook?.apply(this, arguments);
      return hookResponse;
    }
  );
}
export { viteSSRByWeber, viteSSR };
